@@ -40,57 +40,25 @@
 void PASTEMAC(ch,varname) \
      ( \
        struc_t         strucc, \
-       doff_t          diagoffc, \
        diag_t          diagc, \
        uplo_t          uploc, \
        conj_t          conjc, \
        pack_t          schema, \
        bool            invdiag, \
-       dim_t           m_panel, \
-       dim_t           n_panel, \
-       dim_t           m_panel_max, \
-       dim_t           n_panel_max, \
+       dim_t           panel_dim, \
+       dim_t           panel_len, \
+       dim_t           panel_dim_max, \
+       dim_t           panel_len_max, \
+       dim_t           panel_dim_off, \
+       dim_t           panel_len_off, \
        ctype* restrict kappa, \
-       ctype* restrict c, inc_t rs_c, inc_t cs_c, \
-       ctype* restrict p, inc_t rs_p, inc_t cs_p, \
+       ctype* restrict c, inc_t incc, inc_t ldc, \
+       ctype* restrict p,             inc_t ldp, \
                           inc_t is_p, \
-       cntx_t*         cntx  \
+       cntx_t*         cntx, \
+       void*           params \
      ) \
 { \
-	dim_t  panel_dim; \
-	dim_t  panel_dim_max; \
-	dim_t  panel_len; \
-	dim_t  panel_len_max; \
-	inc_t  incc, ldc; \
-	inc_t  ldp; \
-\
-\
-	/* Determine the dimensions and relative strides of the micro-panel
-	   based on its pack schema. */ \
-	if ( bli_is_col_packed( schema ) ) \
-	{ \
-		/* Prepare to pack to row-stored column panel. */ \
-		panel_dim     = n_panel; \
-		panel_dim_max = n_panel_max; \
-		panel_len     = m_panel; \
-		panel_len_max = m_panel_max; \
-		incc          = cs_c; \
-		ldc           = rs_c; \
-		ldp           = rs_p; \
-	} \
-	else /* if ( bli_is_row_packed( schema ) ) */ \
-	{ \
-		/* Prepare to pack to column-stored row panel. */ \
-		panel_dim     = m_panel; \
-		panel_dim_max = m_panel_max; \
-		panel_len     = n_panel; \
-		panel_len_max = n_panel_max; \
-		incc          = rs_c; \
-		ldc           = cs_c; \
-		ldp           = cs_p; \
-	} \
-\
-\
 	/* Handle micro-panel packing based on the structure of the matrix
 	   being packed. */ \
 	if      ( bli_is_general( strucc ) ) \
@@ -108,7 +76,7 @@ void PASTEMAC(ch,varname) \
 		  kappa, \
 		  c, incc, ldc, \
 		  p,       ldp, \
-		  cntx  \
+		  cntx \
 		); \
 	} \
 	else if ( bli_is_herm_or_symm( strucc ) ) \
@@ -118,24 +86,23 @@ void PASTEMAC(ch,varname) \
 		PASTEMAC(ch,packm_herm_cxk_1er) \
 		( \
 		  strucc, \
-		  diagoffc, \
+		  diagc, \
 		  uploc, \
 		  conjc, \
 		  schema, \
-		  m_panel, \
-		  n_panel, \
-		  m_panel_max, \
-		  n_panel_max, \
+		  invdiag, \
 		  panel_dim, \
-		  panel_dim_max, \
 		  panel_len, \
+		  panel_dim_max, \
 		  panel_len_max, \
+		  panel_dim_off, \
+		  panel_len_off, \
 		  kappa, \
-		  c, rs_c, cs_c, \
-		     incc, ldc, \
-		  p, rs_p, cs_p, \
-		           ldp, \
-		  cntx  \
+		  c, incc, ldc, \
+		  p,       ldp, \
+		     is_p, \
+		  cntx, \
+		  params \
 		); \
 	} \
 	else /* ( bli_is_triangular( strucc ) ) */ \
@@ -145,125 +112,25 @@ void PASTEMAC(ch,varname) \
 		PASTEMAC(ch,packm_tri_cxk_1er) \
 		( \
 		  strucc, \
-		  diagoffc, \
 		  diagc, \
 		  uploc, \
 		  conjc, \
 		  schema, \
 		  invdiag, \
-		  m_panel, \
-		  n_panel, \
-		  m_panel_max, \
-		  n_panel_max, \
 		  panel_dim, \
-		  panel_dim_max, \
 		  panel_len, \
+		  panel_dim_max, \
 		  panel_len_max, \
+		  panel_dim_off, \
+		  panel_len_off, \
 		  kappa, \
-		  c, rs_c, cs_c, \
-		     incc, ldc, \
-		  p, rs_p, cs_p, \
-		           ldp, \
-		  cntx  \
+		  c, incc, ldc, \
+		  p,       ldp, \
+		     is_p, \
+		  cntx, \
+		  params \
 		); \
 	} \
-\
-\
-	/* If m_panel < m_panel_max, or n_panel < n_panel_max, we would normally
-	   fill the edge region (the bottom m_panel_max - m_panel rows or right-
-	   side n_panel_max - n_panel columns) of the micropanel with zeros.
-	   However, this responsibility has been moved to the packm microkernel.
-	   This change allows experts to use custom kernels that pack to custom
-	   packing formats when the problem size is not a nice multiple of the
-	   register blocksize. */ \
-/*
-	if ( m_panel != m_panel_max ) \
-	{ \
-		ctype* restrict zero   = PASTEMAC(ch,0); \
-		dim_t           offm   = m_panel; \
-		dim_t           offn   = 0; \
-		dim_t           m_edge = m_panel_max - m_panel; \
-		dim_t           n_edge = n_panel_max; \
-\
-		PASTEMAC(ch,set1ms_mxn) \
-		( \
-		  schema, \
-		  offm, \
-		  offn, \
-		  m_edge, \
-		  n_edge, \
-		  zero, \
-		  p, rs_p, cs_p, ldp  \
-		); \
-	} \
-\
-	if ( n_panel != n_panel_max ) \
-	{ \
-		ctype* restrict zero   = PASTEMAC(ch,0); \
-		dim_t           offm   = 0; \
-		dim_t           offn   = n_panel; \
-		dim_t           m_edge = m_panel_max; \
-		dim_t           n_edge = n_panel_max - n_panel; \
-\
-		PASTEMAC(ch,set1ms_mxn) \
-		( \
-		  schema, \
-		  offm, \
-		  offn, \
-		  m_edge, \
-		  n_edge, \
-		  zero, \
-		  p, rs_p, cs_p, ldp  \
-		); \
-	} \
-*/ \
-\
-	if ( bli_is_triangular( strucc ) ) \
-	{ \
-		/* If this micro-panel is an edge case in both panel dimension and
-		   length, then it must be a bottom-right corner case, which
-		   typically only happens for micro-panels being packed for trsm.
-		   (It also happens for trmm if kr > 1.) Here, we set the part of
-		   the diagonal that extends into the zero-padded region to
-		   identity. This prevents NaNs and Infs from creeping into the
-		   computation. If this code does execute for trmm, it is okay,
-		   because those 1.0's that extend into the bottom-right region
-		   end up getting muliplied by the 0.0's in the zero-padded region
-		   of the other matrix. */ \
-		if ( m_panel != m_panel_max && \
-		     n_panel != n_panel_max ) \
-		{ \
-			ctype* restrict one    = PASTEMAC(ch,1); \
-			dim_t           offm   = m_panel; \
-			dim_t           offn   = n_panel; \
-			dim_t           m_edge = m_panel_max - m_panel; \
-			dim_t           n_edge = n_panel_max - n_panel; \
-\
-			PASTEMAC(ch,set1ms_mxn_diag) \
-			( \
-			  schema, \
-			  offm, \
-			  offn, \
-			  m_edge, \
-			  n_edge, \
-			  one, \
-			  p, rs_p, cs_p, ldp  \
-			); \
-		} \
-	} \
-\
-\
-/*
-	if ( bli_is_1r_packed( schema ) ) { \
-	PASTEMAC(chr,fprintm)( stdout, "packm_struc_cxk_1er (1r): bp", m_panel_max, 2*n_panel_max, \
-	                       ( ctype_r* )p, rs_p, cs_p, "%4.1f", "" ); \
-	} \
- \
-	if ( bli_is_1e_packed( schema ) ) { \
-	PASTEMAC(chr,fprintm)( stdout, "packm_struc_cxk_1er (1e): ap", 2*m_panel_max, 2*n_panel_max, \
-	                       ( ctype_r* )p, rs_p, cs_p, "%4.1f", "" ); \
-	} \
-*/ \
 }
 
 INSERT_GENTFUNCCO_BASIC( packm_struc_cxk_1er, packm_cxk_1er )
@@ -277,42 +144,32 @@ INSERT_GENTFUNCCO_BASIC( packm_struc_cxk_1er, packm_cxk_1er )
 void PASTEMAC(ch,varname) \
      ( \
        struc_t         strucc, \
-       doff_t          diagoffc, \
+       diag_t          diagc, \
        uplo_t          uploc, \
        conj_t          conjc, \
        pack_t          schema, \
-       dim_t           m_panel, \
-       dim_t           n_panel, \
-       dim_t           m_panel_max, \
-       dim_t           n_panel_max, \
+       bool            invdiag, \
        dim_t           panel_dim, \
-       dim_t           panel_dim_max, \
        dim_t           panel_len, \
+       dim_t           panel_dim_max, \
        dim_t           panel_len_max, \
+       dim_t           panel_dim_off, \
+       dim_t           panel_len_off, \
        ctype* restrict kappa, \
-       ctype* restrict c, inc_t rs_c, inc_t cs_c, \
-                          inc_t incc, inc_t ldc, \
-       ctype* restrict p, inc_t rs_p, inc_t cs_p, \
-                                      inc_t ldp, \
-       cntx_t*         cntx  \
+       ctype* restrict c, inc_t incc, inc_t ldc, \
+       ctype* restrict p,             inc_t ldp, \
+                          inc_t is_p, \
+       cntx_t*         cntx, \
+       void*           params \
      ) \
 { \
-	doff_t  diagoffc_abs; \
-	dim_t   j; \
-	bool    row_stored; \
-	bool    col_stored; \
-\
-\
-	/* Create flags to incidate row or column storage. Note that the
-	   schema bit that encodes row or column is describing the form of
-	   micro-panel, not the storage in the micro-panel. Hence the
-	   mismatch in "row" and "column" semantics. */ \
-	row_stored = bli_is_col_packed( schema ); \
-	col_stored = bli_is_row_packed( schema ); \
+	doff_t diagoffc = panel_dim_off - panel_len_off; \
+	doff_t diagoffc_abs; \
+	dim_t  j; \
 \
 	/* Handle the case where the micro-panel does NOT intersect the
 	   diagonal separately from the case where it does intersect. */ \
-	if ( !bli_intersects_diag_n( diagoffc, m_panel, n_panel ) ) \
+	if ( !bli_intersects_diag_n( diagoffc, panel_dim, panel_len ) ) \
 	{ \
 		/* If the current panel is unstored, we need to make a few
 		   adjustments so we refer to the data where it is actually
@@ -320,10 +177,10 @@ void PASTEMAC(ch,varname) \
 		   implicitly assumes we are operating on a dense panel
 		   within a larger symmetric or Hermitian matrix, since a
 		   general matrix would not contain any unstored region.) */ \
-		if ( bli_is_unstored_subpart_n( diagoffc, uploc, m_panel, n_panel ) ) \
+		if ( bli_is_unstored_subpart_n( diagoffc, uploc, panel_dim, panel_len ) ) \
 		{ \
-			c = c + diagoffc * ( doff_t )cs_c + \
-			       -diagoffc * ( doff_t )rs_c;  \
+			c = c + diagoffc * ( doff_t )ldc + \
+			       -diagoffc * ( doff_t )incc;  \
 			bli_swap_incs( &incc, &ldc ); \
 \
 			if ( bli_is_hermitian( strucc ) ) \
@@ -345,7 +202,7 @@ void PASTEMAC(ch,varname) \
 		  cntx  \
 		); \
 	} \
-	else /* if ( bli_intersects_diag_n( diagoffc, m_panel, n_panel ) ) */ \
+	else /* if ( bli_intersects_diag_n( diagoffc, panel_dim, panel_len ) ) */ \
 	{ \
 		ctype* restrict c10; \
 		ctype* restrict p10; \
@@ -366,14 +223,12 @@ void PASTEMAC(ch,varname) \
 		   a micro-panel. If they do, then somehow the constraints on
 		   cache blocksizes being a whole multiple of the register
 		   blocksizes was somehow violated. */ \
-		if ( ( col_stored && diagoffc < 0 ) || \
-		     ( row_stored && diagoffc > 0 ) ) \
+		if ( diagoffc < 0 ) \
 			bli_check_error_code( BLIS_NOT_YET_IMPLEMENTED ); \
 \
 		diagoffc_abs = bli_abs( diagoffc ); \
 \
-		if      ( ( row_stored && bli_is_upper( uploc ) ) || \
-		          ( col_stored && bli_is_lower( uploc ) ) ) \
+		if      ( bli_is_lower( uploc ) ) \
 		{ \
 			p10_dim    = panel_dim; \
 			p10_len    = diagoffc_abs; \
@@ -389,8 +244,8 @@ void PASTEMAC(ch,varname) \
 			diagoffc12 = diagoffc_abs - j; \
 			p12        = p + (j  )*ldp; \
 			c12        = c + (j  )*ldc; \
-			c12        = c12 + diagoffc12 * ( doff_t )cs_c + \
-			                  -diagoffc12 * ( doff_t )rs_c;  \
+			c12        = c12 + diagoffc12 * ( doff_t )ldc + \
+			                  -diagoffc12 * ( doff_t )incc;  \
 			incc12     = ldc; \
 			ldc12      = incc; \
 			conjc12    = conjc; \
@@ -398,16 +253,15 @@ void PASTEMAC(ch,varname) \
 			if ( bli_is_hermitian( strucc ) ) \
 				bli_toggle_conj( &conjc12 ); \
 		} \
-		else /* if ( ( row_stored && bli_is_lower( uploc ) ) || \
-		             ( col_stored && bli_is_upper( uploc ) ) ) */ \
+		else /* if ( bli_is_upper( uploc ) ) */ \
 		{ \
 			p10_dim    = panel_dim; \
 			p10_len    = diagoffc_abs + panel_dim; \
 			diagoffc10 = diagoffc; \
 			p10        = p; \
 			c10        = c; \
-			c10        = c10 + diagoffc10 * ( doff_t )cs_c + \
-			                  -diagoffc10 * ( doff_t )rs_c;  \
+			c10        = c10 + diagoffc10 * ( doff_t )ldc + \
+			                  -diagoffc10 * ( doff_t )incc;  \
 			incc10     = ldc; \
 			ldc10      = incc; \
 			conjc10    = conjc; \
@@ -478,8 +332,8 @@ void PASTEMAC(ch,varname) \
 			  conjc, \
 			  panel_dim, \
 			  kappa, \
-			  c11, rs_c, cs_c, \
-			  p11, rs_p, cs_p, ldp  \
+			  c11, incc, ldc, \
+			  p11,    1, ldp, ldp  \
 			); \
 \
 			/* If we are packing a micro-panel with Hermitian structure,
@@ -495,8 +349,8 @@ void PASTEMAC(ch,varname) \
 			if ( bli_is_hermitian( strucc ) ) \
 			{ \
 				ctype_r* restrict c11_r = ( ctype_r* )c11; \
-				const dim_t       rs_c2 = 2*rs_c; \
-				const dim_t       cs_c2 = 2*cs_c; \
+				const dim_t       incc2 = 2*incc; \
+				const dim_t       ldc2 = 2*ldc; \
 \
 				PASTEMAC3(ch,chr,ch,scal21ms_mxn_diag) \
 				( \
@@ -504,8 +358,8 @@ void PASTEMAC(ch,varname) \
 				  panel_dim, \
 				  panel_dim, \
 				  kappa, \
-				  c11_r, rs_c2, cs_c2, \
-				  p11,   rs_p, cs_p, ldp  \
+				  c11_r, incc2, ldc2, \
+				  p11,   1,     ldp, ldp  \
 				); \
 			} \
 		} \
@@ -523,30 +377,28 @@ INSERT_GENTFUNCCO_BASIC( packm_herm_cxk_1er, packm_cxk_1er )
 void PASTEMAC(ch,varname) \
      ( \
        struc_t         strucc, \
-       doff_t          diagoffp, \
        diag_t          diagc, \
        uplo_t          uploc, \
        conj_t          conjc, \
        pack_t          schema, \
        bool            invdiag, \
-       dim_t           m_panel, \
-       dim_t           n_panel, \
-       dim_t           m_panel_max, \
-       dim_t           n_panel_max, \
        dim_t           panel_dim, \
-       dim_t           panel_dim_max, \
        dim_t           panel_len, \
+       dim_t           panel_dim_max, \
        dim_t           panel_len_max, \
+       dim_t           panel_dim_off, \
+       dim_t           panel_len_off, \
        ctype* restrict kappa, \
-       ctype* restrict c, inc_t rs_c, inc_t cs_c, \
-                          inc_t incc, inc_t ldc, \
-       ctype* restrict p, inc_t rs_p, inc_t cs_p, \
-                                      inc_t ldp, \
-       cntx_t*         cntx  \
+       ctype* restrict c, inc_t incc, inc_t ldc, \
+       ctype* restrict p,             inc_t ldp, \
+                          inc_t is_p, \
+       cntx_t*         cntx, \
+       void*           params \
      ) \
 { \
-	doff_t diagoffp_abs = bli_abs( diagoffp ); \
-	ctype* p11          = p + (diagoffp_abs  )*ldp; \
+	doff_t diagoffc     = panel_dim_off - panel_len_off; \
+	doff_t diagoffc_abs = bli_abs( diagoffc ); \
+	ctype* p11          = p + (diagoffc_abs  )*ldp; \
 \
 \
 	/* Pack the panel. */ \
@@ -579,7 +431,7 @@ void PASTEMAC(ch,varname) \
 			  panel_dim, \
 			  panel_dim, \
 			  kappa, \
-			  p11, rs_p, cs_p, ldp  \
+			  p11, 1, ldp, ldp  \
 			); \
 		} \
 \
@@ -594,7 +446,7 @@ void PASTEMAC(ch,varname) \
 			  0, \
 			  panel_dim, \
 			  panel_dim, \
-			  p11, rs_p, cs_p, ldp  \
+			  p11, 1, ldp, ldp  \
 			); \
 		} \
 \
@@ -610,11 +462,11 @@ void PASTEMAC(ch,varname) \
 		{ \
 			ctype* restrict zero         = PASTEMAC(ch,0); \
 			uplo_t          uplop        = uploc; \
-			doff_t          diagoffp11_0 = 0; \
+			doff_t          diagoffc11_0 = 0; \
 			dim_t           p11_0_dim    = panel_dim - 1; \
 \
 			bli_toggle_uplo( &uplop ); \
-			bli_shift_diag_offset_to_shrink_uplo( uplop, &diagoffp11_0 ); \
+			bli_shift_diag_offset_to_shrink_uplo( uplop, &diagoffc11_0 ); \
 \
 			/* Note that this macro works a little differently than the setm
 			   operation. Here, we pass in the dimensions of only p11, rather
@@ -622,20 +474,51 @@ void PASTEMAC(ch,varname) \
 			   "shrunken" dimensions of p11, corresponding to the toggling
 			   and shrinking of the diagonal above. The macro will do the
 			   right thing, incrementing the pointer to p11 by the appropriate
-			   leading dimension (cs_p or rs_p), and setting only the lower
+			   leading dimension (ldp or rs_p), and setting only the lower
 			   or upper triangle to zero. */ \
 			PASTEMAC(ch,set1ms_mxn_uplo) \
 			( \
 			  schema, \
-			  diagoffp11_0, \
+			  diagoffc11_0, \
 			  uplop, \
 			  p11_0_dim, \
 			  p11_0_dim, \
 			  zero, \
-			  p11, rs_p, cs_p, ldp  \
+			  p11, 1, ldp, ldp  \
 			); \
 		} \
 	} \
+\
+	/* If this micro-panel is an edge case in both panel dimension and
+	   length, then it must be a bottom-right corner case, which
+	   typically only happens for micro-panels being packed for trsm.
+	   (It also happens for trmm if kr > 1.) Here, we set the part of
+	   the diagonal that extends into the zero-padded region to
+	   identity. This prevents NaNs and Infs from creeping into the
+	   computation. If this code does execute for trmm, it is okay,
+	   because those 1.0's that extend into the bottom-right region
+	   end up getting muliplied by the 0.0's in the zero-padded region
+	   of the other matrix. */ \
+	if ( panel_dim != panel_dim_max && \
+	     panel_len != panel_len_max ) \
+	{ \
+		ctype* restrict one    = PASTEMAC(ch,1); \
+		dim_t           offm   = panel_dim; \
+		dim_t           offn   = panel_len; \
+		dim_t           m_edge = panel_dim_max - panel_dim; \
+		dim_t           n_edge = panel_len_max - panel_len; \
+\
+		PASTEMAC(ch,set1ms_mxn_diag) \
+		( \
+		  schema, \
+		  offm, \
+		  offn, \
+		  m_edge, \
+		  n_edge, \
+		  one, \
+		  p, 1, ldp, ldp  \
+		); \
+	} \
 }
 
 INSERT_GENTFUNCCO_BASIC( packm_tri_cxk_1er, packm_cxk_1er )
