@@ -53,7 +53,7 @@ void bli_gemm_check
 	// Check object structure.
 
 	// NOTE: Can't perform these checks as long as bli_gemm_check() is called
-	// from bli_gemm_int(), which is in the execution path for structured
+	// from bli_l3_int(), which is in the execution path for structured
 	// level-3 operations such as hemm.
 
 	//e_val = bli_check_general_object( a );
@@ -98,7 +98,7 @@ void bli_hemm_check
 {
 	err_t e_val;
 
-	// Perform checks common to hemm/symm.
+	// Perform checks common to hemm/symm/trmm/trsm.
 
 	bli_hemm_basic_check( side, alpha, a, b, beta, c, cntx );
 
@@ -109,7 +109,7 @@ void bli_hemm_check
 }
 
 void bli_herk_check
-     ( 
+     (
        obj_t*  alpha,
        obj_t*  a,
        obj_t*  beta,
@@ -197,7 +197,7 @@ void bli_symm_check
 }
 
 void bli_syrk_check
-     ( 
+     (
        obj_t*  alpha,
        obj_t*  a,
        obj_t*  beta,
@@ -248,7 +248,7 @@ void bli_syr2k_check
 	bli_check_error_code( e_val );
 }
 
-void bli_trmm_check
+void bli_trmm3_check
      (
        side_t  side,
        obj_t*  alpha,
@@ -261,7 +261,7 @@ void bli_trmm_check
 {
 	err_t e_val;
 
-	// Perform checks common to hemm/symm.
+	// Perform checks common to hemm/symm/trmm/trsm.
 
 	bli_hemm_basic_check( side, alpha, a, b, beta, c, cntx );
 
@@ -271,22 +271,41 @@ void bli_trmm_check
 	bli_check_error_code( e_val );
 }
 
+void bli_trmm_check
+     (
+       side_t  side,
+       obj_t*  alpha,
+       obj_t*  a,
+       obj_t*  b,
+       cntx_t* cntx
+     )
+{
+	err_t e_val;
+
+	// Perform checks common to hemm/symm/trmm/trsm.
+
+	bli_hemm_basic_check( side, alpha, a, b, &BLIS_ZERO, b, cntx );
+
+	// Check object structure.
+
+	e_val = bli_check_triangular_object( a );
+	bli_check_error_code( e_val );
+}
+
 void bli_trsm_check
      (
        side_t  side,
        obj_t*  alpha,
        obj_t*  a,
        obj_t*  b,
-       obj_t*  beta,
-       obj_t*  c,
        cntx_t* cntx
      )
 {
 	err_t e_val;
 
-	// Perform checks common to hemm/symm.
+	// Perform checks common to hemm/symm/trmm/trsm.
 
-	bli_hemm_basic_check( side, alpha, a, b, beta, c, cntx );
+	bli_hemm_basic_check( side, alpha, a, b, &BLIS_ZERO, b, cntx );
 
 	// Check object structure.
 
@@ -578,10 +597,5 @@ void bli_l3_basic_check
 
 	e_val = bli_check_object_buffer( c );
 	bli_check_error_code( e_val );
-
-	// Check for sufficiently sized stack buffers
-
-	e_val = bli_check_sufficient_stack_buf_size( bli_obj_dt( a ), cntx );
-	bli_check_error_code( e_val );
 }
 
