@@ -51,6 +51,8 @@ void PASTEMAC0(opname) \
 \
 	num_t     dt        = bli_obj_dt( c ); \
 \
+	dim_t     m         = bli_obj_length( c ); \
+	dim_t     n         = bli_obj_width( c ); \
 	dim_t     k         = bli_obj_width( a ); \
 	void*     buf_a     = bli_obj_buffer_at_off( a ); \
 	void*     buf_b     = bli_obj_buffer_at_off( b ); \
@@ -75,6 +77,8 @@ void PASTEMAC0(opname) \
 \
 	f \
 	( \
+	  m, \
+	  n, \
 	  k, \
 	  buf_alpha, \
 	  buf_a, \
@@ -107,6 +111,8 @@ void PASTEMAC0(opname) \
 \
 	num_t     dt        = bli_obj_dt( c11 ); \
 \
+	dim_t     m         = bli_obj_length( c11 ); \
+	dim_t     n         = bli_obj_width( c11 ); \
 	dim_t     k         = bli_obj_width( a1x ); \
 	void*     buf_a1x   = bli_obj_buffer_at_off( a1x ); \
 	void*     buf_a11   = bli_obj_buffer_at_off( a11 ); \
@@ -136,6 +142,8 @@ void PASTEMAC0(opname) \
 \
 		f \
 		( \
+		  m, \
+		  n, \
 		  k, \
 		  buf_alpha, \
 		  buf_a1x, \
@@ -156,6 +164,8 @@ void PASTEMAC0(opname) \
 \
 		f \
 		( \
+		  m, \
+		  n, \
 		  k, \
 		  buf_alpha, \
 		  buf_a1x, \
