@@ -261,6 +261,12 @@ BLIS_INLINE trans_t bli_trans_toggled_conj( trans_t trans )
 	       ( trans ^ BLIS_CONJ_BIT );
 }
 
+BLIS_INLINE trans_t bli_apply_trans( trans_t transapp, trans_t trans )
+{
+	return ( trans_t )
+	       ( trans ^ transapp );
+}
+
 BLIS_INLINE void bli_toggle_trans( trans_t* trans )
 {
 	*trans = bli_trans_toggled( *trans );
@@ -421,6 +427,21 @@ BLIS_INLINE bool bli_is_unit_diag( diag_t diag )
 }
 
 
+// err_t-related
+
+BLIS_INLINE bool bli_is_success( err_t err )
+{
+	return ( bool )
+	       ( err == BLIS_SUCCESS );
+}
+
+BLIS_INLINE bool bli_is_failure( err_t err )
+{
+	return ( bool )
+	       ( err != BLIS_SUCCESS );
+}
+
+
 // dimension-related
 
 BLIS_INLINE bool bli_zero_dim1( dim_t m )
@@ -967,50 +988,6 @@ BLIS_INLINE bool bli_is_panel_packed( pack_t schema )
 	       ( schema & BLIS_PACK_PANEL_BIT );
 }
 
-BLIS_INLINE bool bli_is_4mi_packed( pack_t schema )
-{
-	return ( bool )
-	       ( ( schema & BLIS_PACK_FORMAT_BITS ) == BLIS_BITVAL_4MI );
-}
-
-BLIS_INLINE bool bli_is_3mi_packed( pack_t schema )
-{
-	return ( bool )
-	       ( ( schema & BLIS_PACK_FORMAT_BITS ) == BLIS_BITVAL_3MI );
-}
-
-BLIS_INLINE bool bli_is_3ms_packed( pack_t schema )
-{
-	return ( bool )
-	       ( ( schema & BLIS_PACK_FORMAT_BITS ) == BLIS_BITVAL_3MS );
-}
-
-BLIS_INLINE bool bli_is_ro_packed( pack_t schema )
-{
-	return ( bool )
-	       ( ( schema & BLIS_PACK_FORMAT_BITS ) == BLIS_BITVAL_RO );
-}
-
-BLIS_INLINE bool bli_is_io_packed( pack_t schema )
-{
-	return ( bool )
-	       ( ( schema & BLIS_PACK_FORMAT_BITS ) == BLIS_BITVAL_IO );
-}
-
-BLIS_INLINE bool bli_is_rpi_packed( pack_t schema )
-{
-	return ( bool )
-	       ( ( schema & BLIS_PACK_FORMAT_BITS ) == BLIS_BITVAL_RPI );
-}
-
-BLIS_INLINE bool bli_is_rih_packed( pack_t schema )
-{
-	return ( bool )
-	       ( bli_is_ro_packed( schema ) ||
-	         bli_is_io_packed( schema ) ||
-	         bli_is_rpi_packed( schema ) );
-}
-
 BLIS_INLINE bool bli_is_1r_packed( pack_t schema )
 {
 	return ( bool )
@@ -1049,20 +1026,6 @@ BLIS_INLINE guint_t bli_pack_schema_index( pack_t schema )
 }
 
 
-
-// pointer-related
-
-// Increment a pointer by an integer fraction:
-//   p0 + (num/dem)
-// where p0 is a pointer to a datatype of size sizeof_p0.
-BLIS_INLINE void_fp bli_ptr_inc_by_frac( void_fp p0, siz_t sizeof_p0, dim_t num, dim_t den )
-{
-	return ( void_fp )
-	       ( ( char* )p0 + ( ( num * ( dim_t )sizeof_p0 ) / den ) );
-}
-
-
-
 // Set dimensions, increments, effective uplo/diagoff, etc for ONE matrix
 // argument.
 
