@@ -36,113 +36,53 @@
 #ifndef BLIS_PTHREAD_H
 #define BLIS_PTHREAD_H
 
-#if defined(_MSC_VER)
+// -- Type and macro definitions -----------------------------------------------
+
+#if defined(BLIS_DISABLE_SYSTEM)
+
+// This branch defines a pthread-like API, bli_pthread_*(), and implements it
+// in terms of "dummy" code that doesn't depend on POSIX threads or any other
+// threading mechanism. See issue #454 to see the use case that prompted this
+// feature.
+// NOTE: THIS CODE DOES NOT IMPLEMENT THREADING AND IS NOT THREAD-SAFE!
+
+// -- pthread types --
+
+typedef int bli_pthread_t;
+typedef int bli_pthread_attr_t;
+typedef int bli_pthread_mutex_t;
+typedef int bli_pthread_mutexattr_t;
+typedef int bli_pthread_cond_t;
+typedef int bli_pthread_condattr_t;
+typedef int bli_pthread_once_t;
+
+typedef int bli_pthread_barrier_t;
+typedef int bli_pthread_barrierattr_t;
+
+// -- pthreads macros --
+
+#define BLIS_PTHREAD_MUTEX_INITIALIZER 0
+#define BLIS_PTHREAD_COND_INITIALIZER  0
+#define BLIS_PTHREAD_ONCE_INIT         0
+
+#elif defined(_MSC_VER) // !defined(BLIS_DISABLE_SYSTEM)
 
 // This branch defines a pthread-like API, bli_pthread_*(), and implements it
 // in terms of Windows API calls.
 
-// -- pthread_mutex_*() --
-
-typedef SRWLOCK bli_pthread_mutex_t;
-typedef void bli_pthread_mutexattr_t;
-
-#define BLIS_PTHREAD_MUTEX_INITIALIZER SRWLOCK_INIT
-
-BLIS_EXPORT_BLIS int bli_pthread_mutex_init
-     (
-       bli_pthread_mutex_t*           mutex,
-       const bli_pthread_mutexattr_t* attr
-     );
-
-BLIS_EXPORT_BLIS int bli_pthread_mutex_destroy
-     (
-       bli_pthread_mutex_t* mutex
-     );
-
-BLIS_EXPORT_BLIS int bli_pthread_mutex_lock
-     (
-       bli_pthread_mutex_t* mutex
-     );
-
-BLIS_EXPORT_BLIS int bli_pthread_mutex_trylock
-     (
-       bli_pthread_mutex_t* mutex
-     );
-
-BLIS_EXPORT_BLIS int bli_pthread_mutex_unlock
-     (
-       bli_pthread_mutex_t* mutex
-     );
-
-// -- pthread_once_*() --
-
-typedef INIT_ONCE bli_pthread_once_t;
-
-#define BLIS_PTHREAD_ONCE_INIT INIT_ONCE_STATIC_INIT
-
-BLIS_EXPORT_BLIS void bli_pthread_once
-     (
-       bli_pthread_once_t* once,
-       void              (*init)(void)
-     );
-
-// -- pthread_cond_*() --
-
-typedef CONDITION_VARIABLE bli_pthread_cond_t;
-typedef void bli_pthread_condattr_t;
-
-#define BLIS_PTHREAD_COND_INITIALIZER CONDITION_VARIABLE_INIT
-
-BLIS_EXPORT_BLIS int bli_pthread_cond_init
-     (
-       bli_pthread_cond_t*           cond,
-       const bli_pthread_condattr_t* attr
-     );
-
-BLIS_EXPORT_BLIS int bli_pthread_cond_destroy
-     (
-       bli_pthread_cond_t* cond
-     );
-
-BLIS_EXPORT_BLIS int bli_pthread_cond_wait
-     (
-       bli_pthread_cond_t*  cond,
-       bli_pthread_mutex_t* mutex
-     );
-
-BLIS_EXPORT_BLIS int bli_pthread_cond_broadcast
-     (
-       bli_pthread_cond_t* cond
-     );
-
-// -- pthread_create(), pthread_join() --
+// -- pthread types --
 
 typedef struct
 {
     HANDLE handle;
     void* retval;
 } bli_pthread_t;
-
 typedef void bli_pthread_attr_t;
-
-BLIS_EXPORT_BLIS int bli_pthread_create
-     (
-       bli_pthread_t*            thread,
-       const bli_pthread_attr_t* attr,
-       void*                   (*start_routine)(void*),
-       void*                     arg
-     );
-
-BLIS_EXPORT_BLIS int bli_pthread_join
-     (
-       bli_pthread_t thread,
-       void**        retval
-     );
-
-// -- pthread_barrier_*() --
-
-typedef void bli_pthread_barrierattr_t;
-
+typedef SRWLOCK bli_pthread_mutex_t;
+typedef void bli_pthread_mutexattr_t;
+typedef CONDITION_VARIABLE bli_pthread_cond_t;
+typedef void bli_pthread_condattr_t;
+typedef INIT_ONCE bli_pthread_once_t;
 typedef struct
 {
     bli_pthread_mutex_t mutex;
@@ -150,25 +90,15 @@ typedef struct
     int                 count;
     int                 tripCount;
 } bli_pthread_barrier_t;
+typedef void bli_pthread_barrierattr_t;
 
-BLIS_EXPORT_BLIS int bli_pthread_barrier_init
-     (
-       bli_pthread_barrier_t*           barrier,
-       const bli_pthread_barrierattr_t* attr,
-       unsigned int                     count
-     );
+// -- pthreads macros --
 
-BLIS_EXPORT_BLIS int bli_pthread_barrier_destroy
-     (
-       bli_pthread_barrier_t* barrier
-     );
+#define BLIS_PTHREAD_MUTEX_INITIALIZER SRWLOCK_INIT
+#define BLIS_PTHREAD_ONCE_INIT         INIT_ONCE_STATIC_INIT
+#define BLIS_PTHREAD_COND_INITIALIZER  CONDITION_VARIABLE_INIT
 
-BLIS_EXPORT_BLIS int bli_pthread_barrier_wait
-     (
-       bli_pthread_barrier_t* barrier
-     );
-
-#else // !defined(_MSC_VER)
+#else // !defined(BLIS_DISABLE_SYSTEM) && !defined(_MSC_VER)
 
 #include <pthread.h>
 
@@ -177,13 +107,13 @@ BLIS_EXPORT_BLIS int bli_pthread_barrier_wait
 
 // -- pthread types --
 
-typedef pthread_t              bli_pthread_t;
-typedef pthread_attr_t         bli_pthread_attr_t;
-typedef pthread_mutex_t        bli_pthread_mutex_t;
-typedef pthread_mutexattr_t    bli_pthread_mutexattr_t;
-typedef pthread_cond_t         bli_pthread_cond_t;
-typedef pthread_condattr_t     bli_pthread_condattr_t;
-typedef pthread_once_t         bli_pthread_once_t;
+typedef pthread_t           bli_pthread_t;
+typedef pthread_attr_t      bli_pthread_attr_t;
+typedef pthread_mutex_t     bli_pthread_mutex_t;
+typedef pthread_mutexattr_t bli_pthread_mutexattr_t;
+typedef pthread_cond_t      bli_pthread_cond_t;
+typedef pthread_condattr_t  bli_pthread_condattr_t;
+typedef pthread_once_t      bli_pthread_once_t;
 
 #if defined(__APPLE__)
 
@@ -194,10 +124,10 @@ typedef void bli_pthread_barrierattr_t;
 
 typedef struct
 {
-    bli_pthread_mutex_t mutex;
-    bli_pthread_cond_t  cond;
-    int                 count;
-    int                 tripCount;
+	bli_pthread_mutex_t mutex;
+	bli_pthread_cond_t  cond;
+	int                 count;
+	int                 tripCount;
 } bli_pthread_barrier_t;
 
 #else
@@ -217,6 +147,10 @@ typedef pthread_barrierattr_t  bli_pthread_barrierattr_t;
 #define BLIS_PTHREAD_COND_INITIALIZER  PTHREAD_COND_INITIALIZER
 #define BLIS_PTHREAD_ONCE_INIT         PTHREAD_ONCE_INIT
 
+#endif
+
+// -- Function definitions -----------------------------------------------------
+
 // -- pthread_create(), pthread_join() --
 
 BLIS_EXPORT_BLIS int bli_pthread_create
@@ -285,7 +219,7 @@ BLIS_EXPORT_BLIS int bli_pthread_cond_broadcast
        bli_pthread_cond_t* cond
      );
 
-// -- pthread_once_*() --
+// -- pthread_once() --
 
 BLIS_EXPORT_BLIS void bli_pthread_once
      (
@@ -293,6 +227,30 @@ BLIS_EXPORT_BLIS void bli_pthread_once
        void              (*init)(void)
      );
 
+#if 0
+// NOTE: This part of the API is disabled because (1) we don't actually need
+// _self() or _equal() yet, and (2) when we do try to include these functions,
+// AppVeyor for some reason fails on all the Windows/clang builds with the
+// error:
+//    libblis.a(bli_pthread.o) : error LNK2019: unresolved external symbol
+//     __imp_CompareObjectHandles referenced in function bli_pthread_equal
+
+// -- pthread_self() --
+
+BLIS_EXPORT_BLIS bli_pthread_t bli_pthread_self
+     (
+       void
+     );
+
+// -- pthread_equal() --
+
+BLIS_EXPORT_BLIS int bli_pthread_equal
+     (
+       bli_pthread_t t1,
+       bli_pthread_t t2
+     );
+#endif
+
 // -- pthread_barrier_*() --
 
 BLIS_EXPORT_BLIS int bli_pthread_barrier_init
@@ -312,6 +270,4 @@ BLIS_EXPORT_BLIS int bli_pthread_barrier_wait
        bli_pthread_barrier_t* barrier
      );
 
-#endif // _MSC_VER
-
 #endif // BLIS_PTHREAD_H
