@@ -37,7 +37,9 @@
 
 void bli_sgemm_armv7a_int_4x4
      (
-       dim_t               k0,
+       dim_t               m,
+       dim_t               n,
+       dim_t               k,
        float*     restrict alpha,
        float*     restrict a,
        float*     restrict b,
@@ -49,12 +51,14 @@ void bli_sgemm_armv7a_int_4x4
 {
 	// Typecast local copies of integers in case dim_t and inc_t are a
 	// different size than is expected by load instructions.
-	uint32_t k_iter = k0 / 4;
-	uint32_t k_left = k0 % 4;
+	uint32_t k_iter = k / 4;
+	uint32_t k_left = k % 4;
 	uint32_t rs_c   = rs_c0;
 	uint32_t cs_c   = cs_c0;
 	uint32_t i;
 
+    GEMM_UKR_SETUP_CT( s, 4, 4, false );
+
 	void* a_next = bli_auxinfo_next_a( data );
 	void* b_next = bli_auxinfo_next_b( data );
 
@@ -82,47 +86,17 @@ void bli_sgemm_armv7a_int_4x4
 
 	if ( *beta != 0.0F )
 	{
-		if ( rs_c == 1 )
-		{
-			// Load column 0
-			cv0 = vld1q_f32( c + 0*rs_c + 0*cs_c );
+		// Load column 0
+		cv0 = vld1q_f32( c + 0*cs_c );
 
-			// Load column 1
-			cv1 = vld1q_f32( c + 0*rs_c + 1*cs_c );
+		// Load column 1
+		cv1 = vld1q_f32( c + 1*cs_c );
 
-			// Load column 2
-			cv2 = vld1q_f32( c + 0*rs_c + 2*cs_c );
+		// Load column 2
+		cv2 = vld1q_f32( c + 2*cs_c );
 
-			// Load column 3
-			cv3 = vld1q_f32( c + 0*rs_c + 3*cs_c );
-		}
-		else
-		{
-			// Load column 0
-			cv0 = vld1q_lane_f32( c + 0*rs_c + 0*cs_c, cv0, 0);
-			cv0 = vld1q_lane_f32( c + 1*rs_c + 0*cs_c, cv0, 1);
-			cv0 = vld1q_lane_f32( c + 2*rs_c + 0*cs_c, cv0, 2);
-			cv0 = vld1q_lane_f32( c + 3*rs_c + 0*cs_c, cv0, 3);
-
-			// Load column 1
-			cv1 = vld1q_lane_f32( c + 0*rs_c + 1*cs_c, cv1, 0);
-			cv1 = vld1q_lane_f32( c + 1*rs_c + 1*cs_c, cv1, 1);
-			cv1 = vld1q_lane_f32( c + 2*rs_c + 1*cs_c, cv1, 2);
-			cv1 = vld1q_lane_f32( c + 3*rs_c + 1*cs_c, cv1, 3);
-
-			// Load column 2
-			cv2 = vld1q_lane_f32( c + 0*rs_c + 2*cs_c, cv2, 0);
-			cv2 = vld1q_lane_f32( c + 1*rs_c + 2*cs_c, cv2, 1);
-			cv2 = vld1q_lane_f32( c + 2*rs_c + 2*cs_c, cv2, 2);
-			cv2 = vld1q_lane_f32( c + 3*rs_c + 2*cs_c, cv2, 3);
-
-			// Load column 3
-			cv3 = vld1q_lane_f32( c + 0*rs_c + 3*cs_c, cv3, 0);
-			cv3 = vld1q_lane_f32( c + 1*rs_c + 3*cs_c, cv3, 1);
-			cv3 = vld1q_lane_f32( c + 2*rs_c + 3*cs_c, cv3, 2);
-			cv3 = vld1q_lane_f32( c + 3*rs_c + 3*cs_c, cv3, 3);
-
-		}
+		// Load column 3
+		cv3 = vld1q_f32( c + 3*cs_c );
 	}
 	else
 	{
@@ -255,47 +229,22 @@ void bli_sgemm_armv7a_int_4x4
 		cv3 = vmlaq_f32( cv3, abv3, alphav );
 	}
 
-	if ( rs_c == 1 )
-	{
-		// Store column 0
-		vst1q_f32( c + 0*rs_c + 0*cs_c, cv0 );
-		// Store column 1
-		vst1q_f32( c + 0*rs_c + 1*cs_c, cv1 );
-		// Store column 2
-		vst1q_f32( c + 0*rs_c + 2*cs_c, cv2 );
-		// Store column 3
-		vst1q_f32( c + 0*rs_c + 3*cs_c, cv3 );
-	}
-	else
-	{
-		// Store column 0
-		vst1q_lane_f32( c + 0*rs_c + 0*cs_c, cv0, 0);
-		vst1q_lane_f32( c + 1*rs_c + 0*cs_c, cv0, 1);
-		vst1q_lane_f32( c + 2*rs_c + 0*cs_c, cv0, 2);
-		vst1q_lane_f32( c + 3*rs_c + 0*cs_c, cv0, 3);
+	// Store column 0
+	vst1q_f32( c + 0*cs_c, cv0 );
+	// Store column 1
+	vst1q_f32( c + 1*cs_c, cv1 );
+	// Store column 2
+	vst1q_f32( c + 2*cs_c, cv2 );
+	// Store column 3
+	vst1q_f32( c + 3*cs_c, cv3 );
 
-		// Store column 1
-		vst1q_lane_f32( c + 0*rs_c + 1*cs_c, cv1, 0);
-		vst1q_lane_f32( c + 1*rs_c + 1*cs_c, cv1, 1);
-		vst1q_lane_f32( c + 2*rs_c + 1*cs_c, cv1, 2);
-		vst1q_lane_f32( c + 3*rs_c + 1*cs_c, cv1, 3);
-
-		// Store column 2
-		vst1q_lane_f32( c + 0*rs_c + 2*cs_c, cv2, 0);
-		vst1q_lane_f32( c + 1*rs_c + 2*cs_c, cv2, 1);
-		vst1q_lane_f32( c + 2*rs_c + 2*cs_c, cv2, 2);
-		vst1q_lane_f32( c + 3*rs_c + 2*cs_c, cv2, 3);
-
-		// Store column 3
-		vst1q_lane_f32( c + 0*rs_c + 3*cs_c, cv3, 0);
-		vst1q_lane_f32( c + 1*rs_c + 3*cs_c, cv3, 1);
-		vst1q_lane_f32( c + 2*rs_c + 3*cs_c, cv3, 2);
-		vst1q_lane_f32( c + 3*rs_c + 3*cs_c, cv3, 3);
-	}
+    GEMM_UKR_FLUSH_CT( s );
 }
 
 void bli_dgemm_armv7a_int_4x4
      (
+       dim_t               m,
+       dim_t               n,
        dim_t               k,
        double*    restrict alpha,
        double*    restrict a,
@@ -314,6 +263,8 @@ void bli_dgemm_armv7a_int_4x4
 	uint32_t cs_c   = cs_c0;
 	uint32_t i;
 
+    GEMM_UKR_SETUP_CT_ANY( d, 4, 4, false );
+
 	//void* a_next = bli_auxinfo_next_a( data );
 	//void* b_next = bli_auxinfo_next_b( data );
 
@@ -330,53 +281,53 @@ void bli_dgemm_armv7a_int_4x4
 	double b0, b1, b2, b3;
 	double B0, B1, B2, B3;
 
-	double  ab00, ab01, ab02, ab03; 
-	double  ab10, ab11, ab12, ab13; 
+	double  ab00, ab01, ab02, ab03;
+	double  ab10, ab11, ab12, ab13;
 	double  ab20, ab21, ab22, ab23;
-	double  ab30, ab31, ab32, ab33; 
+	double  ab30, ab31, ab32, ab33;
 
-	double* restrict c00, * restrict c01, * restrict c02, * restrict c03; 
+	double* restrict c00, * restrict c01, * restrict c02, * restrict c03;
 	double* restrict c10, * restrict c11, * restrict c12, * restrict c13;
 	double* restrict c20, * restrict c21, * restrict c22, * restrict c23;
-	double* restrict c30, * restrict c31, * restrict c32, * restrict c33; 
+	double* restrict c30, * restrict c31, * restrict c32, * restrict c33;
 
 	double* restrict ap = a;
-        double* restrict bp = b; 
+        double* restrict bp = b;
 
 	double* restrict Ap = a + 4;
-        double* restrict Bp = b + 4; 
+        double* restrict Bp = b + 4;
 
-	c00 = (c + 0*rs_c + 0*cs_c); 
-	c10 = (c + 1*rs_c + 0*cs_c); 
-	c20 = (c + 2*rs_c + 0*cs_c); 
-	c30 = (c + 3*rs_c + 0*cs_c); 
+	c00 = (c + 0*rs_c + 0*cs_c);
+	c10 = (c + 1*rs_c + 0*cs_c);
+	c20 = (c + 2*rs_c + 0*cs_c);
+	c30 = (c + 3*rs_c + 0*cs_c);
 
-	c01 = (c + 0*rs_c + 1*cs_c); 
-	c11 = (c + 1*rs_c + 1*cs_c); 
-	c21 = (c + 2*rs_c + 1*cs_c); 
-	c31 = (c + 3*rs_c + 1*cs_c); 
+	c01 = (c + 0*rs_c + 1*cs_c);
+	c11 = (c + 1*rs_c + 1*cs_c);
+	c21 = (c + 2*rs_c + 1*cs_c);
+	c31 = (c + 3*rs_c + 1*cs_c);
 
-	c02 = (c + 0*rs_c + 2*cs_c); 
-	c12 = (c + 1*rs_c + 2*cs_c); 
-	c22 = (c + 2*rs_c + 2*cs_c); 
-	c32 = (c + 3*rs_c + 2*cs_c); 
+	c02 = (c + 0*rs_c + 2*cs_c);
+	c12 = (c + 1*rs_c + 2*cs_c);
+	c22 = (c + 2*rs_c + 2*cs_c);
+	c32 = (c + 3*rs_c + 2*cs_c);
 
-	c03 = (c + 0*rs_c + 3*cs_c); 
-	c13 = (c + 1*rs_c + 3*cs_c); 
-	c23 = (c + 2*rs_c + 3*cs_c); 
-	c33 = (c + 3*rs_c + 3*cs_c); 
+	c03 = (c + 0*rs_c + 3*cs_c);
+	c13 = (c + 1*rs_c + 3*cs_c);
+	c23 = (c + 2*rs_c + 3*cs_c);
+	c33 = (c + 3*rs_c + 3*cs_c);
 
 	ab00 = 0.0; ab10 = 0.0; ab20 = 0.0; ab30 = 0.0;
 	ab01 = 0.0; ab11 = 0.0; ab21 = 0.0; ab31 = 0.0;
 	ab02 = 0.0; ab12 = 0.0; ab22 = 0.0; ab32 = 0.0;
 	ab03 = 0.0; ab13 = 0.0; ab23 = 0.0; ab33 = 0.0;
 
-	A0 = *(Ap + 0); 
-	A1 = *(Ap + 1); 
-	A2 = *(Ap + 2); 
-	A3 = *(Ap + 3); 
+	A0 = *(Ap + 0);
+	A1 = *(Ap + 1);
+	A2 = *(Ap + 2);
+	A3 = *(Ap + 3);
 
-	a0 = *(ap + 0); 
+	a0 = *(ap + 0);
 	a1 = *(ap + 1);
  	a2 = *(ap + 2);
 
@@ -389,11 +340,11 @@ void bli_dgemm_armv7a_int_4x4
 	b1 = *(bp + 1);
 	b2 = *(bp + 2);
 
-	double *Aplast = (Ap + 4*(k-k_left)); 
+	double *Aplast = (Ap + 4*(k-k_left));
 
 	//for ( i = 0; i < k_iter; ++i ) // Unroll by factor 4.
 	for ( ; Ap != Aplast ; ) // Unroll by factor 4.
-	{ 
+	{
 		/* Prefetch */
 		//__asm__ ("pld\t[%0],#100\n\t" : :"r"(Ap) : );
 		__builtin_prefetch( ap + 112 );
@@ -452,7 +403,7 @@ void bli_dgemm_armv7a_int_4x4
 		b2 = *(bp + 10);
 
 		ab03 += a0 * b3;
-		a0 = *(ap + 8); 
+		a0 = *(ap + 8);
 		ab13 += a1 * b3;
 		a1 = *(ap + 9);
 		ab23 += a2 * b3;
@@ -460,17 +411,17 @@ void bli_dgemm_armv7a_int_4x4
 		ab33 += a3 * b3;
 		//a3 = *(ap + 11);
 
-		ap += 8; 
-		Ap += 8; 
-		bp += 8; 
-		Bp += 8; 
+		ap += 8;
+		Ap += 8;
+		bp += 8;
+		Bp += 8;
 
-	} 
+	}
 
 
-	for ( i = 0; i < k_left; ++i ) 
-	{ 
-		a0 = *(ap + 0); 
+	for ( i = 0; i < k_left; ++i )
+	{
+		a0 = *(ap + 0);
 		a1 = *(ap + 1);
 		a2 = *(ap + 2);
 		a3 = *(ap + 3);
@@ -500,48 +451,75 @@ void bli_dgemm_armv7a_int_4x4
 		ab23 += a2 * b3;
 		ab33 += a3 * b3;
 
-		ap += 4; 
-		bp += 4; 
-	} 
+		ap += 4;
+		bp += 4;
+	}
 
-	*c00 = *c00 * *beta;
-	*c10 = *c10 * *beta;
-	*c20 = *c20 * *beta;
-	*c30 = *c30 * *beta;
+    if ( *beta == 0.0 )
+    {
+    	*c00 = ab00 * *alpha;
+    	*c10 = ab10 * *alpha;
+    	*c20 = ab20 * *alpha;
+    	*c30 = ab30 * *alpha;
 
-	*c01 = *c01 * *beta;
-	*c11 = *c11 * *beta;
-	*c21 = *c21 * *beta;
-	*c31 = *c31 * *beta;
+    	*c01 = ab01 * *alpha;
+    	*c11 = ab11 * *alpha;
+    	*c21 = ab21 * *alpha;
+    	*c31 = ab31 * *alpha;
 
-	*c02 = *c02 * *beta;
-	*c12 = *c12 * *beta;
-	*c22 = *c22 * *beta;
-	*c32 = *c32 * *beta;
+    	*c02 = ab02 * *alpha;
+    	*c12 = ab12 * *alpha;
+    	*c22 = ab22 * *alpha;
+    	*c32 = ab32 * *alpha;
 
-	*c03 = *c03 * *beta;
-	*c13 = *c13 * *beta;
-	*c23 = *c23 * *beta;
-	*c33 = *c33 * *beta;
+    	*c03 = ab03 * *alpha;
+    	*c13 = ab13 * *alpha;
+    	*c23 = ab23 * *alpha;
+    	*c33 = ab33 * *alpha;
+    }
+    else
+    {
+    	*c00 = *c00 * *beta;
+    	*c10 = *c10 * *beta;
+    	*c20 = *c20 * *beta;
+    	*c30 = *c30 * *beta;
 
-	*c00 += ab00 * *alpha;
-	*c10 += ab10 * *alpha;
-	*c20 += ab20 * *alpha;
-	*c30 += ab30 * *alpha;
+    	*c01 = *c01 * *beta;
+    	*c11 = *c11 * *beta;
+    	*c21 = *c21 * *beta;
+    	*c31 = *c31 * *beta;
 
-	*c01 += ab01 * *alpha;
-	*c11 += ab11 * *alpha;
-	*c21 += ab21 * *alpha;
-	*c31 += ab31 * *alpha;
+    	*c02 = *c02 * *beta;
+    	*c12 = *c12 * *beta;
+    	*c22 = *c22 * *beta;
+    	*c32 = *c32 * *beta;
 
-	*c02 += ab02 * *alpha;
-	*c12 += ab12 * *alpha;
-	*c22 += ab22 * *alpha;
-	*c32 += ab32 * *alpha;
+    	*c03 = *c03 * *beta;
+    	*c13 = *c13 * *beta;
+    	*c23 = *c23 * *beta;
+    	*c33 = *c33 * *beta;
 
-	*c03 += ab03 * *alpha;
-	*c13 += ab13 * *alpha;
-	*c23 += ab23 * *alpha;
-	*c33 += ab33 * *alpha;
+    	*c00 += ab00 * *alpha;
+    	*c10 += ab10 * *alpha;
+    	*c20 += ab20 * *alpha;
+    	*c30 += ab30 * *alpha;
+
+    	*c01 += ab01 * *alpha;
+    	*c11 += ab11 * *alpha;
+    	*c21 += ab21 * *alpha;
+    	*c31 += ab31 * *alpha;
+
+    	*c02 += ab02 * *alpha;
+    	*c12 += ab12 * *alpha;
+    	*c22 += ab22 * *alpha;
+    	*c32 += ab32 * *alpha;
+
+    	*c03 += ab03 * *alpha;
+    	*c13 += ab13 * *alpha;
+    	*c23 += ab23 * *alpha;
+    	*c33 += ab33 * *alpha;
+    }
+
+    GEMM_UKR_FLUSH_CT( d );
 }
 
