@@ -1,7 +1,9 @@
 function r_val = plot_dom_all( cfreq, ...
                                dflopspercycle, ...
                                nth, ...
-                               dirpath )
+                               dirpath, ...
+                               dirpath_out, ...
+                               arch_str )
 
 cases( 1, : ) = [ 'rrr' ];
 cases( 2, : ) = [ 'rrc' ];
@@ -22,7 +24,9 @@ for i = 1:n_cases
 	               cfreq, ...
 	               dflopspercycle, ...
 	               nth, ...
-	               dirpath );
+	               dirpath, ...
+	               dirpath_out, ...
+	               arch_str );
 end
 
 r_val = 0;
