@@ -266,6 +266,11 @@ void libblis_test_amaxv_check
 	//bli_obj_scalar_init_detached( BLIS_INT, &index );
 	//bli_amaxv( x, &index );
 	bli_getsc( index, &i_d, &junk ); i = i_d;
+
+	// If x is length 0, then we can't access any elements, and so we
+	// return early with a good residual.
+	if ( bli_obj_vector_dim( x ) == 0 ) { *resid = 0.0; return; }
+
 	bli_acquire_vi( i, x, &chi_i );
 
 	bli_obj_scalar_init_detached( BLIS_INT, &index_test );
