@@ -169,7 +169,6 @@ void libblis_test_gemm_ukr_experiment
 	num_t        datatype;
 
 	dim_t        m, n, k;
-	inc_t        ldap, ldbp;
 
 	char         sc_a = 'c';
 	char         sc_b = 'r';
@@ -194,11 +193,6 @@ void libblis_test_gemm_ukr_experiment
 	m = bli_cntx_get_blksz_def_dt( datatype, BLIS_MR, cntx );
 	n = bli_cntx_get_blksz_def_dt( datatype, BLIS_NR, cntx );
 
-	// Also query PACKMR and PACKNR as the leading dimensions to ap and bp,
-	// respectively.
-	ldap = bli_cntx_get_blksz_max_dt( datatype, BLIS_MR, cntx );
-	ldbp = bli_cntx_get_blksz_max_dt( datatype, BLIS_NR, cntx );
-
 	// Store the register blocksizes so that the driver can retrieve the
 	// values later when printing results.
 	op->dim_aux[0] = m;
@@ -237,7 +231,13 @@ void libblis_test_gemm_ukr_experiment
 	libblis_test_mobj_randomize( params, TRUE, &c );
 	bli_copym( &c, &c_save );
 
-#if 0
+	rntm_t rntm;
+	bli_rntm_init( &rntm );
+	bli_pba_rntm_set_pba( &rntm );
+
+	// Transpose B to B^T for packing.
+	bli_obj_induce_trans( &b );
+
 	// Create pack objects for a and b, and pack them to ap and bp,
 	// respectively.
 	cntl_t* cntl_a = libblis_test_pobj_create
@@ -248,56 +248,26 @@ void libblis_test_gemm_ukr_experiment
 	  BLIS_PACKED_ROW_PANELS,
 	  BLIS_BUFFER_FOR_A_BLOCK,
 	  &a, &ap,
-	  cntx
+	  cntx,
+	  &rntm
 	);
 	cntl_t* cntl_b = libblis_test_pobj_create
 	(
-	  BLIS_KR,
 	  BLIS_NR,
+	  BLIS_KR,
 	  BLIS_NO_INVERT_DIAG,
 	  BLIS_PACKED_COL_PANELS,
 	  BLIS_BUFFER_FOR_B_PANEL,
 	  &b, &bp,
-	  cntx
+	  cntx,
+	  &rntm
 	);
-#endif
 
-	// Create the packed objects. Use packmr and packnr as the leading
-	// dimensions of ap and bp, respectively. Note that we use the ldims
-	// instead of the matrix dimensions for allocation purposes here.
-	// This is a little hacky and was prompted when trying to support
-	// configurations such as power9 that employ duplication/broadcasting
-	// of elements in one of the packed matrix objects. Thankfully, packm
-	// doesn't care about those dimensions and instead relies on
-	// information taken from the source object. Thus, this is merely
-	// about coaxing bli_obj_create() in allocating enough space for our
-	// purposes.
-	bli_obj_create( datatype, ldap, k, 1, ldap, &ap );
-	bli_obj_create( datatype, k, ldbp, ldbp, 1, &bp );
+	// Transpose B^T back to B and Bp^T back to Bp.
+	bli_obj_induce_trans( &b );
+	bli_obj_induce_trans( &bp );
 
-	// Set up the objects for packing. Calling packm_init_pack() does everything
-	// except checkout a memory pool block and save its address to the obj_t's.
-	// However, it does overwrite the buffer field of packed object with that of
-	// the source object (as a side-effect of bli_obj_alias_to(); that buffer
-	// field would normally be overwritten yet again by the address from the
-	// memory pool block). So, we have to save the buffer address that was
-	// allocated so we can re-store it to the object afterward.
-	void* buf_ap = bli_obj_buffer( &ap );
-	void* buf_bp = bli_obj_buffer( &bp );
-	bli_packm_init_pack( BLIS_NO_INVERT_DIAG, BLIS_PACKED_ROW_PANELS,
-	                     BLIS_PACK_FWD_IF_UPPER, BLIS_PACK_FWD_IF_LOWER,
-	                     BLIS_MR, BLIS_KR, &a, &ap, cntx );
-	bli_packm_init_pack( BLIS_NO_INVERT_DIAG, BLIS_PACKED_COL_PANELS,
-	                     BLIS_PACK_FWD_IF_UPPER, BLIS_PACK_FWD_IF_LOWER,
-	                     BLIS_KR, BLIS_NR, &b, &bp, cntx );
-	bli_obj_set_buffer( buf_ap, &ap );
-	bli_obj_set_buffer( buf_bp, &bp );
-
-	// Pack the data from the source objects.
-	bli_packm_blk_var1( &a, &ap, cntx, NULL, &BLIS_PACKM_SINGLE_THREADED );
-	bli_packm_blk_var1( &b, &bp, cntx, NULL, &BLIS_PACKM_SINGLE_THREADED );
-
-	// Repeat the experiment n_repeats times and record results. 
+	// Repeat the experiment n_repeats times and record results.
 	for ( i = 0; i < n_repeats; ++i )
 	{
 		bli_copym( &c_save, &c );
@@ -321,16 +291,10 @@ void libblis_test_gemm_ukr_experiment
 	// Zero out performance and residual if output matrix is empty.
 	libblis_test_check_empty_problem( &c, perf, resid );
 
-#if 0
 	// Free the control tree nodes and release their cached mem_t entries
-	// back to the memory broker.
-	bli_cntl_free( cntl_a, &BLIS_PACKM_SINGLE_THREADED );
-	bli_cntl_free( cntl_b, &BLIS_PACKM_SINGLE_THREADED );
-#endif
-
-	// Free the packed objects.
-	bli_obj_free( &ap );
-	bli_obj_free( &bp );
+	// back to the pba.
+	bli_cntl_free( &rntm, cntl_a, &BLIS_PACKM_SINGLE_THREADED );
+	bli_cntl_free( &rntm, cntl_b, &BLIS_PACKM_SINGLE_THREADED );
 
 	// Free the test objects.
 	bli_obj_free( &a );
